==> ejc-proequipmentcorp-impl-3.0.0-20221124.024157-181-sources.jar: com/ejianc/business/proequipmentcorprent/appearance/bean/AppearanceSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.appearance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备出场-设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_appearance_sub")
public class AppearanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_exit_code")
    private String equipmentExitCode; // 设备出厂编码
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类别ID
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_name_id")
    private Long equipmentNameId; // 设备名称ID
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="billing_unit")
    private String billingUnit; // 计量单位
    @TableField(value="rent_type")
    private String rentType; // 计租方式
    @TableField(value="approach_date")
    private Date approachDate; // 进场日期
    @TableField(value="appearance_date")
    private Date appearanceDate; // 出场日期
    @TableField(value="rent_end_date")
    private Date rentEndDate; // 止租日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="source_id")
    private Long sourceId;//来源id


    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentExitCode() {
        return equipmentExitCode;
    }

    public void setEquipmentExitCode(String equipmentExitCode) {
        this.equipmentExitCode = equipmentExitCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getEquipmentNameId() {
        return equipmentNameId;
    }

    public void setEquipmentNameId(Long equipmentNameId) {
        this.equipmentNameId = equipmentNameId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBillingUnit() {
        return billingUnit;
    }

    public void setBillingUnit(String billingUnit) {
        this.billingUnit = billingUnit;
    }
    public String getRentType() {
        return rentType;
    }

    public void setRentType(String rentType) {
        this.rentType = rentType;
    }
    public Date getApproachDate() {
        return approachDate;
    }

    public void setApproachDate(Date approachDate) {
        this.approachDate = approachDate;
    }
    public Date getAppearanceDate() {
        return appearanceDate;
    }

    public void setAppearanceDate(Date appearanceDate) {
        this.appearanceDate = appearanceDate;
    }
    public Date getRentEndDate() {
        return rentEndDate;
    }

    public void setRentEndDate(Date rentEndDate) {
        this.rentEndDate = rentEndDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20230323.082600-355-sources.jar: com/ejianc/business/proequipmentcorprent/appearance/bean/AppearanceSubEntity.java <==
package com.ejianc.business.proequipmentcorprent.appearance.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备出场-设备明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proequipmentcorp_appearance_sub")
public class AppearanceSubEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value="equipment_exit_code")
    private String equipmentExitCode; // 设备出厂编码
    @TableField(value="equipment_type")
    private String equipmentType; // 设备类别
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备类别ID
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_name_id")
    private Long equipmentNameId; // 设备名称ID
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="billing_unit")
    private String billingUnit; // 计量单位
    @TableField(value="rent_type")
    private String rentType; // 计租方式
    @TableField(value="approach_date")
    private Date approachDate; // 进场日期
    @TableField(value="appearance_date")
    private Date appearanceDate; // 出场日期
    @TableField(value="rent_end_date")
    private Date rentEndDate; // 止租日期
    @TableField(value="detail_memo")
    private String detailMemo; // 备注
    @TableField(value="contract_id")
    private Long contractId; // 合同id
    @TableField(value="pid")
    private Long pid; // 主表id
    @TableField(value="source_id")
    private Long sourceId;//来源id
    @TableField(value="state")
    private Integer state; // 状态:2--启用 3-停用 4-退场 5-待启用 6-停租

    public Integer getState() {
        return state;
    }

    public void setState(Integer state) {
        this.state = state;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getEquipmentExitCode() {
        return equipmentExitCode;
    }

    public void setEquipmentExitCode(String equipmentExitCode) {
        this.equipmentExitCode = equipmentExitCode;
    }
    public String getEquipmentType() {
        return equipmentType;
    }

    public void setEquipmentType(String equipmentType) {
        this.equipmentType = equipmentType;
    }
    public Long getEquipmentTypeId() {
        return equipmentTypeId;
    }

    public void setEquipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getEquipmentName() {
        return equipmentName;
    }

    public void setEquipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public Long getEquipmentNameId() {
        return equipmentNameId;
    }

    public void setEquipmentNameId(Long equipmentNameId) {
        this.equipmentNameId = equipmentNameId;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public String getBillingUnit() {
        return billingUnit;
    }

    public void setBillingUnit(String billingUnit) {
        this.billingUnit = billingUnit;
    }
    public String getRentType() {
        return rentType;
    }

    public void setRentType(String rentType) {
        this.rentType = rentType;
    }
    public Date getApproachDate() {
        return approachDate;
    }

    public void setApproachDate(Date approachDate) {
        this.approachDate = approachDate;
    }
    public Date getAppearanceDate() {
        return appearanceDate;
    }

    public void setAppearanceDate(Date appearanceDate) {
        this.appearanceDate = appearanceDate;
    }
    public Date getRentEndDate() {
        return rentEndDate;
    }

    public void setRentEndDate(Date rentEndDate) {
        this.rentEndDate = rentEndDate;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    
}
